@@ -1,10 +1,10 @@
 /**********************************************************************
  * vanessa_logger.c                                      September 2000
- * Horms                                             horms@verge.net.au
+ * Simon Horman                                      horms@verge.net.au
  *
  * vanessa_logger
  * Generic logging layer
- * Copyright (C) 2000-2004  Horms
+ * Copyright (C) 2000-2008  Simon Horman <horms@verge.net.au>
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -1198,10 +1198,10 @@ int vanessa_logger_reopen(vanessa_logger_t * vl)
 
 static char *
 __vanessa_logger_str_dump_oct(vanessa_logger_t * vl, 
-		const unsigned char *buffer, const size_t buffer_length)
+		const char *buffer, const size_t buffer_length)
 {
-	const unsigned char *in_pos;
-	const unsigned char *in_top;
+	const char *in_pos;
+	const char *in_top;
 	char *out_pos;
 	char *out;
 
@@ -1220,38 +1220,38 @@ __vanessa_logger_str_dump_oct(vanessa_logger_t * vl,
 			case '\a':
 				*out_pos++ = '\\';
 				*out_pos++ = 'a';
-				goto loop;
+				continue;
 			case '\b':
 				*out_pos++ = '\\';
 				*out_pos++ = 'b';
-				goto loop;
+				continue;
 			case '\t':
 				*out_pos++ = '\\';
 				*out_pos++ = 't';
-				goto loop;
+				continue;
 			case '\n':
 				*out_pos++ = '\\';
 				*out_pos++ = 'n';
-				goto loop;
+				continue;
 			case '\v':
 				*out_pos++ = '\\';
 				*out_pos++ = 'v';
-				goto loop;
+				continue;
 			case '\f':
 				*out_pos++ = '\\';
 				*out_pos++ = 'f';
-				goto loop;
+				continue;
 			case '\r':
 				*out_pos++ = '\\';
 				*out_pos++ = 'r';
-				goto loop;
+				continue;
 			case '\\': 
 			case '"': 
 			case '\'':
 				*out_pos++ = '\\';
 			case ' ':
 				*out_pos++ = *in_pos;
-				goto loop;
+				continue;
 		}
 		if (isgraph(*in_pos) || *in_pos == ' ') {
 			*out_pos++ = *in_pos;
@@ -1260,8 +1260,6 @@ __vanessa_logger_str_dump_oct(vanessa_logger_t * vl,
 			sprintf(out_pos, "\\%03o", *in_pos);
 			out_pos += 4;
 		}
-loop:
-		continue;
 	}
 
 	*out_pos++ = '\0';
@@ -1281,11 +1279,11 @@ loop:
 
 
 static char *
-__vanessa_logger_str_dump_hex(vanessa_logger_t * vl, 
-		const unsigned char *buffer, const size_t buffer_length)
+__vanessa_logger_str_dump_hex(vanessa_logger_t * vl, const char *buffer,
+			      const size_t buffer_length)
 {
-	const unsigned char *in_pos;
-	const unsigned char *in_top;
+	const char *in_pos;
+	const char *in_top;
 	char *out_pos;
 	char *out;
 	int i;
@@ -1316,14 +1314,40 @@ __vanessa_logger_str_dump_hex(vanessa_logger_t * vl,
 
 
 char *
-vanessa_logger_str_dump(vanessa_logger_t * vl, const unsigned char *buffer, 
+vanessa_logger_str_dump(vanessa_logger_t * vl, const char *buffer, 
 		const size_t buffer_length, vanessa_logger_flag_t flag)
 {
 	if(flag == VANESSA_LOGGER_STR_DUMP_HEX) {
-		return(__vanessa_logger_str_dump_hex(vl, buffer, 
-					buffer_length));
+		return(__vanessa_logger_str_dump_hex(vl, buffer,
+						     buffer_length));
 	}
 
 	return(__vanessa_logger_str_dump_oct(vl, buffer, buffer_length));
 }			 
 
+
+/**********************************************************************
+ * vanessa_logger_vl_set_filehandle
+ * set the logger function to a logger created for the filehandle 
+ * No logging will take place using conveineince macros if logger is set to
+ * NULL (default). That is you _must_ call one of the vanessa_logger_vl_set
+ * functions to enable logging using convenience macros.
+ * pre:  fd: filehandle to log to 
+ * post: logger for filehandle is created and set as the 
+ *       logger for convenience marcros 
+ * created for the filehandle return: none
+ **********************************************************************/
+
+vanessa_logger_t *
+vanessa_logger_set_filehandle(FILE *fh)
+{
+	vanessa_logger_t *vl;
+	vl = vanessa_logger_openlog_filehandle(stderr, "romocon", LOG_DEBUG,
+					       VANESSA_LOGGER_F_NO_IDENT_PID);
+	if (!vl)
+		return NULL;
+	return vanessa_logger_set(vl);
+}
+
+
+
