@@ -1,10 +1,10 @@
 /**********************************************************************
  * vanessa_logger_sample.c                               September 2000
- * Horms                                             horms@verge.net.au
+ * Simon Horman                                      horms@verge.net.au
  *
  * vanessa_logger
  * Generic logging layer
- * Copyright (C) 2000-2004  Horms
+ * Copyright (C) 2000-2008  Simon Horman <horms@verge.net.au>
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <stdarg.h>
+#include <stdlib.h>
 
 #include "vanessa_logger_sample_config.h"
 
@@ -48,7 +49,7 @@ int main (int argc, char **argv){
   vanessa_logger_t *log_sl_bn=NULL;
   vanessa_logger_t *log_fu=NULL;
 
-  printf("vanessa_logger_sample version %s Copyright Horms\n", VERSION);
+  printf("vanessa_logger_sample version %s Copyright Simon Horman\n", VERSION);
 
 
   /* 
